/*! \file lib_io_tp.h
    \brief Librairie E/S via TCP pour le CESI.
    \author Bertrand Vandeportaele IUT GEII
    \date  14/02/2022
*/
#ifndef LIB_IO_TP_H
#define LIB_IO_TP_H

// Bertrand Vandeportaele 2022
// inspiré d'un exemple de client TCP simple sans QT:
// https://riptutorial.com/cplusplus/example/24000/hello-tcp-client

#include "Arduino.h"


#include <cstring>
#include <iostream>
#include <string>
#include <arpa/inet.h>
#include <netdb.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <unistd.h>

/*!
 * \brief setupES Configure les entrées sorties émulées ou télé-opérées vers l'hôte ipAddressInit via le port TCP portNumInit
 * \param ipAddressInit
 * \param portNumInit
 * \return
 */
int setupES(char *ipAddressInit,char *portNumInit);
/*!
 * \brief closeES Libère les ressources de communications utilisées par la librairie
 */
void closeES();
/*!
 * \brief readPort Lit l'état du port d'entrée 8 bits
 * \return l'état du port d'entrée 8 bits
 */
unsigned char readPort(void);
/*!
 * \brief writePort Pilote l'état du port de sortie 8 bits
 * \param value l'état du port de sortie 8 bits
 */
void writePort(unsigned char value);
/*!
/*! * \brief setName Règle votre nom à afficher sur l'écran LCD ou dans la zone de texte de l'émulateur
/*! * \param value la chaine de caractères contenant votre nom
/*! */
void setName(char *value);
/*!
 * \brief setMsg Règle un message à afficher sur l'écran LCD ou dans la zone de texte de l'émulateur
 * \param value la chaine de caractères contenant le message
 */
void setMsg(char *value);
// formats de requetes TCP:
//  g \n         pour lecture port
//  s val\n      pour ecriture port
//  n nom\n      pour affichage nom
//  m message\n  pour affichage message

#endif // LIB_IO_TP_H

